{% if pillar['ceph-salt']['time_server']['enabled'] %}
{% set time_server = pillar['ceph-salt']['time_server']['server_hosts'][0] %}
{% set time_server_is_minion = time_server in pillar['ceph-salt']['minions']['all'] %}

{% import 'macros.yml' as macros %}

{{ macros.begin_stage('Sync clocks') }}

/tmp/chrony_sync_clock.sh:
  file.managed:
    - source:
        - salt://ceph-salt/apply/files/chrony_sync_clock.sh
    - user: root
    - group: root
    - mode: '0755'
    - makedirs: True
    - backup: minion
    - failhard: True

{% if time_server_is_minion and grains['id'] != time_server %}

{{ macros.begin_step('Wait for time server node to signal that it has synced its clock') }}
wait for time server sync:
  ceph_salt.wait_for_grain:
    - grain: ceph-salt:execution:timeserversynced
    - hosts: [ {{ time_server }} ]
    - failhard: True
{{ macros.end_step('Wait for time server node to signal that it has synced its clock') }}

{% endif %}

{{ macros.begin_step('Force clock sync now') }}

run sync script:
  cmd.run:
    - name: |
        /tmp/chrony_sync_clock.sh
    - failhard: True

{{ macros.end_step('Force clock sync now') }}

{% if grains['id'] == time_server %}
{{ macros.begin_step('Signal that time server node has synced its clock') }}
set timeserversynced:
  grains.present:
    - name: ceph-salt:execution:timeserversynced
    - value: True
{{ macros.end_step('Signal that time server node has synced its clock') }}
{% endif %}

delete clock sync script:
  file.absent:
    - name: |
        /tmp/chrony_sync_clock.sh
    - failhard: True

{{ macros.end_stage('Sync clocks') }}

{% endif %}

prevent empty time-sync:
  test.nop
